@@ -5,25 +5,57 @@
 
 package edu.harvard.hul.ois.jhove;
 
-import edu.harvard.hul.ois.jhove.handler.AuditHandler;
-import edu.harvard.hul.ois.jhove.handler.TextHandler;
-import edu.harvard.hul.ois.jhove.handler.XmlHandler;
-import edu.harvard.hul.ois.jhove.module.BytestreamModule;
+import java.io.BufferedInputStream;
+import java.io.BufferedOutputStream;
+import java.io.DataInputStream;
+import java.io.EOFException;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileNotFoundException;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.io.OutputStreamWriter;
+import java.io.PrintWriter;
+import java.io.RandomAccessFile;
+import java.io.UnsupportedEncodingException;
+import java.net.MalformedURLException;
+import java.net.URI;
+import java.net.URISyntaxException;
+import java.net.URL;
+import java.net.URLConnection;
+import java.net.UnknownHostException;
+import java.text.MessageFormat;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Date;
+import java.util.List;
+import java.util.Map;
+import java.util.Properties;
+import java.util.TreeMap;
+import java.util.logging.Level;
+import java.util.logging.Logger;
+
+import javax.net.ssl.HostnameVerifier;
+import javax.net.ssl.HttpsURLConnection;
+import javax.net.ssl.SSLContext;
+import javax.net.ssl.SSLSession;
+import javax.net.ssl.SSLSocketFactory;
+import javax.net.ssl.TrustManager;
+import javax.net.ssl.X509TrustManager;
+import javax.xml.parsers.SAXParserFactory;
+
 import org.openpreservation.jhove.ReleaseDetails;
 import org.xml.sax.SAXException;
 import org.xml.sax.XMLReader;
 import org.xml.sax.helpers.XMLReaderFactory;
 
-import javax.net.ssl.*;
-import javax.xml.parsers.SAXParserFactory;
-import java.io.*;
-import java.net.URI;
-import java.net.URL;
-import java.net.URLConnection;
-import java.net.UnknownHostException;
-import java.util.*;
-import java.util.logging.Level;
-import java.util.logging.Logger;
+import edu.harvard.hul.ois.jhove.handler.AuditHandler;
+import edu.harvard.hul.ois.jhove.handler.JsonHandler;
+import edu.harvard.hul.ois.jhove.handler.TextHandler;
+import edu.harvard.hul.ois.jhove.handler.XmlHandler;
+import edu.harvard.hul.ois.jhove.module.BytestreamModule;
 
 /**
  * The JHOVE engine, providing all base services necessary to build an
@@ -80,10 +112,6 @@ public class JhoveBase {
     private static final String TEMPDIR_PROPERTY = JHOVE_PROPERTY_PREFIX
             + "tempDirectory";
 
-    /** MIX schema version property. */
-    private static final String MIXVSN_PROPERTY = JHOVE_PROPERTY_PREFIX
-            + "mixvsn";
-
     /** Flag for aborting activity. */
     protected boolean _abort;
     /** Buffer size for buffered I/O. */
@@ -93,8 +121,6 @@ public class JhoveBase {
     protected String _configFile;
     /** Selected encoding. */
     protected String _encoding;
-    /** Associate map of configuration extensions. */
-    protected Map<String, String> _extensions;
     /** Ordered list of output handlers. */
     protected List<OutputHandler> _handlerList;
     /** Map of output handlers (for fast access by name). */
@@ -136,9 +162,9 @@ public class JhoveBase {
      * Class constructor.
      *
      * Instantiates a <code>JhoveBase</code> object.
-     * 
+     *
      * @throws JhoveException
-     *             if invoked with a JVM lower than 1.6
+     *             if invoked with a JVM lower than 1.8
      */
     public JhoveBase() throws JhoveException {
 
@@ -147,7 +173,7 @@ public class JhoveBase {
 
         // Make sure we have a satisfactory version of Java.
         String version = System.getProperty("java.vm.version");
-        if (version.compareTo("1.6.0") < 0) {
+        if (version.compareTo("1.8.0") < 0) {
             _logger.severe(CoreMessageConstants.EXC_JAVA_VER_INCMPT);
             throw new JhoveException(CoreMessageConstants.EXC_JAVA_VER_INCMPT);
         }
@@ -157,11 +183,11 @@ public class JhoveBase {
                 new NaiveHostnameVerifier());
 
         // Initialize the engine.
-        _moduleList = new ArrayList<Module>(20);
-        _moduleMap = new TreeMap<String, Module>();
+        _moduleList = new ArrayList<>(20);
+        _moduleMap = new TreeMap<>();
 
-        _handlerList = new ArrayList<OutputHandler>();
-        _handlerMap = new TreeMap<String, OutputHandler>();
+        _handlerList = new ArrayList<>();
+        _handlerMap = new TreeMap<>();
 
         _abort = false;
         _bufferSize = -1;
@@ -216,7 +242,8 @@ public class JhoveBase {
             }
         } catch (Exception e) {
             // If we can't get a SAX parser, we're stuck.
-            throw new JhoveException(CoreMessageConstants.EXC_SAX_PRSR_MISS + saxClass, e);
+            throw new JhoveException(CoreMessageConstants.EXC_SAX_PRSR_MISS
+                    + saxClass, e);
         }
 
         _logger.info("Using SAX parser " + parser.getClass().getName());
@@ -251,9 +278,13 @@ public class JhoveBase {
 
         // Update the application state to reflect the configuration file,
         // if necessary.
-        _extensions = configHandler.getExtensions();
         _jhoveHome = configHandler.getJhoveHome();
 
+        // Set language code if changed in properties
+        if (!configHandler.getLanguage().isEmpty()) {
+            System.setProperty("module.language", configHandler.getLanguage());
+        }
+
         _encoding = configHandler.getEncoding();
         if (_encoding == null) {
             _encoding = getFromProperties(ENCODING_PROPERTY);
@@ -299,7 +330,8 @@ public class JhoveBase {
             if (size != null) {
                 try {
                     _bufferSize = Integer.parseInt(size);
-                } catch (Exception e) {
+                } catch (NumberFormatException nfe) {
+                    // Not a valid integer, so ignore it.
                 }
             }
             if (_bufferSize < 0) {
@@ -307,7 +339,7 @@ public class JhoveBase {
             }
         }
 
-        // Retrieve the ordered lists of modules and output handlers
+        // Retrieve the ordered list of modules
         List<ModuleInfo> modList = configHandler.getModule();
         List<List<String>> params = configHandler.getModuleParams();
         for (int i = 0; i < modList.size(); i++) {
@@ -321,13 +353,14 @@ public class JhoveBase {
 
                 _moduleList.add(module);
                 _moduleMap.put(module.getName().toLowerCase(), module);
-                _logger.info("Initialized " + module.getName());
+                _logger.fine("Initialized " + module.getName());
             } catch (Exception e) {
                 throw new JhoveException(CoreMessageConstants.EXC_MODL_INST_FAIL
                         + modInfo.clas, e);
             }
         }
 
+        // Retrieve the list of output handlers
         List<String[]> hanList = configHandler.getHandler();
         params = configHandler.getHandlerParams();
         for (int i = 0; i < hanList.size(); i++) {
@@ -350,22 +383,27 @@ public class JhoveBase {
         // are always statically loaded.
 
         Module module = new BytestreamModule();
-        module.setDefaultParams(new ArrayList<String>());
+        module.setDefaultParams(new ArrayList<>());
         _moduleList.add(module);
         _moduleMap.put(module.getName().toLowerCase(), module);
 
         OutputHandler handler = new TextHandler();
-        handler.setDefaultParams(new ArrayList<String>());
+        handler.setDefaultParams(new ArrayList<>());
         _handlerList.add(handler);
         _handlerMap.put(handler.getName().toLowerCase(), handler);
 
         handler = new XmlHandler();
-        handler.setDefaultParams(new ArrayList<String>());
+        handler.setDefaultParams(new ArrayList<>());
+        _handlerList.add(handler);
+        _handlerMap.put(handler.getName().toLowerCase(), handler);
+
+        handler = new JsonHandler();
+        handler.setDefaultParams(new ArrayList<>());
         _handlerList.add(handler);
         _handlerMap.put(handler.getName().toLowerCase(), handler);
 
         handler = new AuditHandler();
-        handler.setDefaultParams(new ArrayList<String>());
+        handler.setDefaultParams(new ArrayList<>());
         _handlerList.add(handler);
         _handlerMap.put(handler.getName().toLowerCase(), handler);
     }
@@ -387,7 +425,7 @@ public class JhoveBase {
      * information about that handler.
      * <li>If they're both null, provides information about the application.
      * </ul>
-     * 
+     *
      * @param app
      *            The App object for the application
      * @param module
@@ -414,10 +452,12 @@ public class JhoveBase {
         handler.reset();
         _outputFile = outputFile;
 
+        _logger.info("Preparing " + handler.getName()
+                + " handler to write to \""
+                + (_outputFile == null ? "STDOUT" : _outputFile) + "\"");
+
         handler.setApp(app);
         handler.setBase(this);
-        _logger.info("Handler " + handler.getClass().getName()
-                + " preparing to write to " + _outputFile);
         handler.setWriter(makeWriter(_outputFile, _encoding));
 
         handler.showHeader();
@@ -456,8 +496,7 @@ public class JhoveBase {
         if (_abort) {
             return false;
         }
-        _logger.info("Entering JhoveBase.process, file/uri = "
-                + dirFileOrUri);
+        _logger.info("Processing \"" + dirFileOrUri + "\"");
         File file = null;
         boolean isTemp = false;
         long lastModified = -1;
@@ -466,7 +505,7 @@ public class JhoveBase {
         URI uri = null;
         try {
             uri = new URI(dirFileOrUri);
-        } catch (Exception e) {
+        } catch (URISyntaxException use) {
             // We may get an exception on Windows paths,
             // if so then fall through and try for a file.
         }
@@ -475,7 +514,7 @@ public class JhoveBase {
             URL url = null;
             try {
                 url = uri.toURL();
-            } catch (Exception e) {
+            } catch (MalformedURLException mue) {
                 throw new JhoveException(CoreMessageConstants.EXC_URI_CONV_FAIL
                         + dirFileOrUri);
             }
@@ -542,13 +581,13 @@ public class JhoveBase {
         } else {
 
             if (!file.exists()) {
-                _logger.info("File not found");
-                info.setMessage(new ErrorMessage(CoreMessageConstants.ERR_FILE_NOT_FOUND));
+                _logger.info("File not found: \"" + file.getPath() + "\"");
+                info.setMessage(new ErrorMessage(CoreMessageConstants.JHOVE_CORE_1));
                 info.setWellFormed(RepInfo.UNDETERMINED);
                 info.show(handler);
             } else if (!file.isFile() || !file.canRead()) {
-                _logger.info("File cannot be read");
-                info.setMessage(new ErrorMessage(CoreMessageConstants.ERR_FILE_READ));
+                _logger.info("File cannot be read: \"" + file.getPath() + "\"");
+                info.setMessage(new ErrorMessage(CoreMessageConstants.JHOVE_CORE_2));
                 info.setWellFormed(RepInfo.UNDETERMINED);
                 info.show(handler);
             } else if (handler.okToProcess(dirFileOrUri)) {
@@ -559,28 +598,30 @@ public class JhoveBase {
                 info.setLastModified(new Date(lastModified));
 
                 if (module != null) {
-
-                    // Invoke the specified module.
-                    _logger.info("Processing " + file.getName()
-                            + " with module " + module.getClass().getName());
                     try {
+                        // Invoke the specified module.
                         if (!processFile(app, module, false, file, info)) {
                             return false;
                         }
                     } catch (Exception e) {
-                        info.setMessage(new ErrorMessage(CoreMessageConstants.EXC_UNEXPECTED));
+                        _logger.log(Level.SEVERE,
+                                CoreMessageConstants.JHOVE_CORE_5.getMessage(), e);
+                        info.setMessage(new ErrorMessage(
+                                CoreMessageConstants.JHOVE_CORE_5));
                         info.setWellFormed(RepInfo.UNDETERMINED);
-                        _logger.log(Level.SEVERE, CoreMessageConstants.EXC_UNEXPECTED, e);
                     }
                 } else {
 
+                    _logger.info("Discovering compatible modules...");
+
                     // Invoke all modules until one returns well-formed. If a
                     // module doesn't know how to validate, we don't want to
                     // throw arbitrary files at it, so we'll skip it.
                     for (Module mod : _moduleList) {
-                        RepInfo infc = (RepInfo) info.clone();
 
                         if (mod.hasFeature("edu.harvard.hul.ois.jhove.canValidate")) {
+                            RepInfo infc = (RepInfo) info.clone();
+
                             try {
                                 if (!processFile(app, mod, false, file, infc)) {
                                     return false;
@@ -599,7 +640,7 @@ public class JhoveBase {
                                 // the wrong type of file, the module may go off
                                 // its track and throw an exception, so we just
                                 // continue on to the next module.
-                                _logger.info("JHOVE caught exception: "
+                                _logger.fine("JHOVE caught exception: "
                                         + e.getClass().getName());
                             }
                         }
@@ -722,6 +763,10 @@ public class JhoveBase {
             if (value != null) {
                 info.setChecksum(new Checksum(value, ChecksumType.SHA1));
             }
+            value = ckSummer.getSHA256();
+            if (value != null) {
+                info.setChecksum(new Checksum(value, ChecksumType.SHA256));
+            }
         }
         return tempFile;
     }
@@ -763,6 +808,10 @@ public class JhoveBase {
         if (!module.hasFeature("edu.harvard.hul.ois.jhove.canValidate")) {
             return false;
         }
+
+        _logger.info("Processing \"" + file.getPath() + "\" with "
+                + module.getName() + " module");
+
         if (_callback != null) {
             _callback.callback(2, info.getUri());
         }
@@ -863,20 +912,6 @@ public class JhoveBase {
         return _encoding;
     }
 
-    /**
-     * Returns the JHOVE configuration extensions.
-     */
-    public Map<String, String> getExtension() {
-        return _extensions;
-    }
-
-    /**
-     * Returns the JHOVE configuration extension by name.
-     */
-    public String getExtension(String name) {
-        return _extensions.get(name);
-    }
-
     /**
      * Returns a handler by name.
      */
@@ -1062,7 +1097,7 @@ public class JhoveBase {
         if (level != null) {
             try {
                 _logger.setLevel(Level.parse(_logLevel));
-            } catch (Exception e) {
+            } catch (SecurityException se) {
             }
         }
     }
@@ -1103,6 +1138,17 @@ public class JhoveBase {
         _currentThread = t;
     }
 
+    /**
+     * Sets the maximum number of bytes to check, for modules that look for
+     * an indefinitely positioned signature or check the first sigBytes bytes
+     * in lieu of a signature.
+     *
+     * @param sigBytes max number of bytes to check
+     */
+    public void setSigBytes(int sigBytes) {
+        _sigBytes = sigBytes;
+    }
+
     /**
      * Resets the abort flag. This must be called at the beginning of any
      * activity for which the abort flag may subsequently be set.
@@ -1162,7 +1208,7 @@ public class JhoveBase {
 
     /**
      * Creates an output PrintWriter.
-     * 
+     *
      * @param outputFile
      *            Output filepath. If null, writer goes to System.out.
      * @param encoding
@@ -1179,8 +1225,10 @@ public class JhoveBase {
                 osw = new OutputStreamWriter(stream, encoding);
                 output = new PrintWriter(osw);
             } catch (UnsupportedEncodingException uee) {
-                throw new JhoveException(CoreMessageConstants.EXC_CHAR_ENC_UNSPPTD
-                        + encoding);
+                throw new JhoveException(
+                    MessageFormat.format(
+                        CoreMessageConstants.JHOVE_CORE_4.getMessage(),
+                        encoding));
             } catch (FileNotFoundException fnfe) {
                 throw new JhoveException(CoreMessageConstants.EXC_FILE_OPEN
                         + outputFile);
@@ -1190,8 +1238,10 @@ public class JhoveBase {
             try {
                 osw = new OutputStreamWriter(System.out, encoding);
             } catch (UnsupportedEncodingException uee) {
-                throw new JhoveException(CoreMessageConstants.EXC_CHAR_ENC_UNSPPTD
-                        + encoding);
+                throw new JhoveException(
+                    MessageFormat.format(
+                        CoreMessageConstants.JHOVE_CORE_4.getMessage(),
+                        encoding));
             }
             output = new PrintWriter(osw);
         }
@@ -1210,7 +1260,7 @@ public class JhoveBase {
      * A HostnameVerifier for HTTPS connections that will never ask for
      * certificates.
      */
-    private class NaiveHostnameVerifier implements HostnameVerifier {
+    private static class NaiveHostnameVerifier implements HostnameVerifier {
         public boolean verify(String hostname, SSLSession session) {
             return true;
         }
@@ -1219,7 +1269,7 @@ public class JhoveBase {
     /**
      * A TrustManager which should accept all certificates.
      */
-    private class RelaxedX509TrustManager implements X509TrustManager {
+    private static class RelaxedX509TrustManager implements X509TrustManager {
         public boolean isClientTrusted(
                 java.security.cert.X509Certificate[] chain) {
             return true;
