@@ -6,10 +6,11 @@
 package edu.harvard.hul.ois.jhove;
 
 import java.awt.color.ICC_Profile;
-import java.io.UnsupportedEncodingException;
 import java.nio.ByteBuffer;
+import java.nio.charset.StandardCharsets;
 import java.util.logging.Logger;
-
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
 /**
  * Encapsulation of the NISO Z39.87-2002 / AIIM 20-2002 Data Dictionary --
@@ -19,7 +20,12 @@ public class NisoImageMetadata
 {
 	/** Logger for this class. */
     private static final Logger LOGGER = Logger.getLogger(NisoImageMetadata.class.getCanonicalName());
-    
+
+    /** private String constants. */
+    private static final String YES = "Yes";
+    private static final String NO = "No";
+    private static final String TIME_SEP = ":";
+
     /******************************************************************
      * PUBLIC CLASS FIELDS.
      ******************************************************************/
@@ -42,7 +48,7 @@ public class NisoImageMetadata
 
     /** 6.2.3.1 Checksum method value labels. */
     public static final String [] CHECKSUM_METHOD = {
-	"CRC32", "MD5", "SHA-1"
+	"CRC32", "MD5", "SHA-1", "SHA-256"
     };
 
     /** 6.1.4.1 Color space value labels. */
@@ -53,20 +59,24 @@ public class NisoImageMetadata
     "CFA",
     "CIE Log2(L)",
     "CIE Log2(L)(u',v')",
-    "LinearRaw"
+    "LinearRaw",
+    "YCCK"
     };
+
     /** Index for 6.1.4.1 color space value labels. */
     public static final int [] COLORSPACE_INDEX = {
-	0, 1, 2, 3, 
+	0, 1, 2, 3,
     4, 5, 6, 8, 9,
     10,
     32803,
     32844,
     32845,
-    34892
+    34892,
+    65535
     };
 
     /** 6.1.3.1 Compression scheme value labels. */
+    /* Taken from the TIFFTAG_COMPRESSION */
     public static final String [] COMPRESSION_SCHEME = {
 	"uncompressed", "CCITT 1D", "CCITT Group 3", "CCITT Group 4", /* 1-4 */
 	"LZW", "JPEG", "ISO JPEG", "Deflate",                 /* 5-8 */
@@ -81,24 +91,32 @@ public class NisoImageMetadata
 	"Kodak DCS",                                          /* 32947 */
 	"SGI 32-bit Log Luminance encoding",                  /* 34676 */
 	"SGI 24-bit Log Luminance encoding",                  /* 34677 */
-	"JPEG 2000"                                           /* 34712 */
+	"JPEG 2000",                                          /* 34712 */
+	"JPEG2000 Lossy",                                     /* 34713 non standard !!! */
+	"JPEG2000 Lossless",                                  /* 34714 non standard !!! */
+	"LZMA"												  /* 34925 */
     };
     /** Index for 6.1.3.1 compression scheme value labels. */
+    public static final int COMPRESSION_JPEG2000_LOSSY = 34713;
+    public static final int COMPRESSION_JPEG2000_LOSSLESS = 34714;
     public static final int [] COMPRESSION_SCHEME_INDEX = {
-	1, 2, 3, 4, 
-	5, 6, 7, 8, 
+	1, 2, 3, 4,
+	5, 6, 7, 8,
 	32661,
 	32771,
-	32773, 32766, 32809, 
-	32895, 
-	32896, 32897, 32898, 
+	32773, 32766, 32809,
+	32895,
+	32896, 32897, 32898,
 	32908,
-	32909, 
-	32946, 
+	32909,
+	32946,
 	32947,
-	34676, 
+	34676,
 	34677,
-	34712
+	34712,
+	34713,  /* non standard !!! */
+	34714,  /* non standard !!! */
+	34925
     };
 
     /** 6.2.5 display orientation value labels. */
@@ -113,20 +131,23 @@ public class NisoImageMetadata
 
     public static final String [] EXPOSURE_PROGRAM = {
 	"Not defined", " Manual", "Normal program", "Aperture priority",
-	"Shutter priority", "Creative program (biased toward depth of field)", 
+	"Shutter priority", "Creative program (biased toward depth of field)",
 	"Action program (biased toward fast shutter speed)",
 	"Portrait mode (for closeup photos with the background out of focus)",
 	"Landscape mode (for landscape photos with the background in focus)"
     };
-    
+
     /** 7.7.3.10 flash value labels. */
     public static final String [] FLASH = {
-	"yes", "no"
+	NO, YES
+    };
+    public static final String [] FLASH_20 = {
+	"Flash did not fire", "Flash fired"
     };
 
     /** 7.7.3.12 flash return value labels. */
     public static final String [] FLASH_RETURN = {
-	"yes", "no"
+	YES, NO
     };
 
     /** 8.2.6 gray response unit value labels for version 0.2. */
@@ -135,7 +156,7 @@ public class NisoImageMetadata
 	"thousandths of a unit", "ten-thousandths of a unit",
 	"hundred-thousandths of a unit"
     };
-    
+
     /** Gray response unit value for version 2.0 of MIX, corresponding
      *  to NISO values of 1-5 */
     public static final String [] GRAY_RESPONSE_UNIT_20 = {
@@ -154,7 +175,7 @@ public class NisoImageMetadata
 	    "unassociated alpha data",
 	    "range or depth data"
 	};
-	
+
     /** 7.7.3.6 metering mode value labels. */
     public static final String [] METERING_MODE = {
 	"unidentified", "average", "center weighted average", "spot",
@@ -164,7 +185,7 @@ public class NisoImageMetadata
     /** 6.2.4 orientation value labels. */
     public static final String [] ORIENTATION = {
 	"", "normal", "reflected horiz", "rotated 180 deg", "reflected vert",
-	"left top", "rotated cw 90 deg", "Right bottom", "Rotated ccw 90 deg", 
+	"left top", "rotated cw 90 deg", "Right bottom", "Rotated ccw 90 deg",
 	"Unknown"
     };
 
@@ -306,6 +327,19 @@ public class NisoImageMetadata
     /** 6.3 Preferred presentation */
     private String _preferredPresentation;
 
+    /******************************************************************
+    * Special Format Characteristics
+    * From Data Dictionary - Technical Metadata for Digital Still Images
+    * (ANSI/NISO Z39.87-2006)
+    * Only used for JPEG2000 format
+    ******************************************************************/
+    /** 7.2.1.2.1 tiles */
+    private String _jp2Tiles;
+    /** 7.2.1.2.2 qualityLayers */
+    private int _jp2Layers;
+    /** 7.2.1.2.3resolutionLevels */
+    private int _jp2ResolutionLevels;
+    
     /******************************************************************
      * 7 Image creation
      ******************************************************************/
@@ -363,15 +397,15 @@ public class NisoImageMetadata
     private double _fNumber;
     /** 7.7.3.2 Exposure time */
     private double _exposureTime;
-    
+
     private int _exposureProgram;
     private String _exifVersion;
     private Rational _maxApertureValue;
-    
+
     /** 7.7.3.3 Brightness */
-    private double _brightness;
+    private Rational _brightness;
     /** 7.7.3.4 Exposure bias */
-    private double _exposureBias;
+    private Rational _exposureBias;
     /** 7.7.3.5 Subject distance */
     private double [] _subjectDistance;
     /** 7.7.3.6 Metering mode */
@@ -385,7 +419,7 @@ public class NisoImageMetadata
     /** 7.7.3.10 Flash */
     private int _flash;
     /** 7.7.3.11 Flash energy */
-    private double _flashEnergy;
+    private Rational _flashEnergy;
     /** 7.7.3.12 Flash return */
     private int _flashReturn;
     /** 7.7.3.13 Back light */
@@ -521,7 +555,7 @@ public class NisoImageMetadata
     {
 	_autoFocus = NULL;
 	_backLight = NULL;
-	_brightness = NILL;
+	_brightness = null;
 	_checksumMethod = NULL;
 	_colorSpace = NULL;
 	_colorTemp = NILL;
@@ -534,13 +568,13 @@ public class NisoImageMetadata
 	_digitalCameraModelSerialNo = null;
 	_displayOrientation = NULL;
 	_exifVersion = null;
-	_exposureBias = NILL;
+	_exposureBias = null;
 	_exposureIndex = NILL;
 	_exposureProgram = NULL;
 	_exposureTime = NILL;
 	_fileSize = NULL;
 	_flash = NULL;
-	_flashEnergy = NILL;
+	_flashEnergy = null;
 	_flashReturn = NULL;
 	_fNumber = NILL;
 	_focalLength = NILL;
@@ -548,6 +582,9 @@ public class NisoImageMetadata
 	_imageData = null;
 	_imageLength = NULL;
 	_imageWidth = NULL;
+	_jp2Layers = NULL;
+	_jp2ResolutionLevels = NULL;
+	_jp2Tiles = null;
 	_maxApertureValue = null;
 	_meteringMode = NULL;
 	_orientation = NULL;
@@ -596,7 +633,7 @@ public class NisoImageMetadata
 
     /******************************************************************
      * PUBLIC INSTANCE METHODS.
-     * 
+     *
      * Accessor methods.
      ******************************************************************/
 
@@ -619,7 +656,7 @@ public class NisoImageMetadata
     }
 
     /** Get 7.7.3.3 Brightness. */
-    public double getBrightness ()
+    public Rational getBrightness ()
     {
 	return _brightness;
     }
@@ -746,7 +783,7 @@ public class NisoImageMetadata
     }
 
     /** Get 7.7.3.4 exposure bias. */
-    public double getExposureBias ()
+    public Rational getExposureBias ()
     {
 	return _exposureBias;
     }
@@ -761,7 +798,7 @@ public class NisoImageMetadata
     {
 	return _exposureProgram;
     }
-    
+
     /** Get 7.7.3.2 exposure time. */
     public double getExposureTime ()
     {
@@ -787,7 +824,7 @@ public class NisoImageMetadata
     }
 
     /** Get 7.7.3.11 flash energy. */
-    public double getFlashEnergy ()
+    public Rational getFlashEnergy ()
     {
 	return _flashEnergy;
     }
@@ -929,7 +966,31 @@ public class NisoImageMetadata
 	return _preferredPresentation;
     }
 
-    /** Get 8.2.8.5 primary chromaticities blue X. */
+	public String getJp2Tiles() {
+		return _jp2Tiles;
+	}
+
+	public void setJp2Tiles(String jp2Tiles) {
+		this._jp2Tiles = jp2Tiles;
+	}
+
+	public int getJp2Layers() {
+		return _jp2Layers;
+	}
+
+	public void setJp2Layers(int jp2Layers) {
+		this._jp2Layers = jp2Layers;
+	}
+
+	public int getJp2ResolutionLevels() {
+		return _jp2ResolutionLevels;
+	}
+
+	public void setJp2ResolutionLevels(int jp2ResolutionLevels) {
+		this._jp2ResolutionLevels = jp2ResolutionLevels;
+	}
+
+	/** Get 8.2.8.5 primary chromaticities blue X. */
     public Rational getPrimaryChromaticitiesBlueX ()
     {
 	return _primaryChromaticitiesBlueX;
@@ -1317,7 +1378,7 @@ public class NisoImageMetadata
     /** Set 7.7.3.3 brightness.
      * @param brightness Brightness
      */
-    public void setBrightness (double brightness)
+    public void setBrightness (Rational brightness)
     {
 	_brightness = brightness;
     }
@@ -1406,9 +1467,9 @@ public class NisoImageMetadata
      *  TIFF dates get converted to ISO 8601 format.
      * @param date Date/time created
      */
-    public void setDateTimeCreated (String date)
+    public void setDateTimeCreated(String date)
     {
-	_dateTimeCreated = make8601Valid (date);
+        _dateTimeCreated = make8601Valid(date);
     }
 
     /** Set 9.1.1  DateTimeProcessed.
@@ -1417,7 +1478,7 @@ public class NisoImageMetadata
      */
     public void setDateTimeProcessed (String date)
     {
-    	_dateTimeProcessed = make8601Valid (date);
+        _dateTimeProcessed = make8601Valid(date);
     }
 
     /** Set 7.5 Device source.
@@ -1437,7 +1498,7 @@ public class NisoImageMetadata
     }
 
     /** Set 7.7.2 digital camera model.
-     * @param model Camera model
+     * @param modelName Camera model
      */
     public void setDigitalCameraModelName (String modelName)
     {
@@ -1464,11 +1525,11 @@ public class NisoImageMetadata
     {
     	_exifVersion = version;
     }
-    
+
     /** Set 7.2.3.4 exposure bias.
      * @param bias Exposure bias
      */
-    public void setExposureBias (double bias)
+    public void setExposureBias (Rational bias)
     {
 	_exposureBias = bias;
     }
@@ -1500,7 +1561,7 @@ public class NisoImageMetadata
     public void setExtraSamples (int [] extra)
     {
 	_extraSamples = extra;
-    }	    
+    }
 
     /** Set 6.2.2 file size.
      * @param size File size
@@ -1521,7 +1582,7 @@ public class NisoImageMetadata
     /** Set 7.7.3.11 flash energy.
      * @param energy Flash energy
      */
-    public void setFlashEnergy (double energy)
+    public void setFlashEnergy (Rational energy)
     {
 	_flashEnergy = energy;
     }
@@ -1779,8 +1840,8 @@ public class NisoImageMetadata
          _processingSoftwareName = name;
     }
 
-    /** Set 9.1.4.2  ProcessingSoftwareVersion 
-     *  @param version  Version number of the processing software 
+    /** Set 9.1.4.2  ProcessingSoftwareVersion
+     *  @param version  Version number of the processing software
      */
     public void setProcessingSoftwareVersion (String version)
     {
@@ -2041,7 +2102,7 @@ public class NisoImageMetadata
 	_tileLength = length;
     }
 
-    /** Set 6.1.5.7 Tile offsets. 
+    /** Set 6.1.5.7 Tile offsets.
      * @param offsets tile offsets
      */
     public void setTileOffsets (long [] offsets)
@@ -2161,7 +2222,7 @@ public class NisoImageMetadata
 	_yTargetedDisplayAR = y;
     }
 
-    /** Set information for Swing GUI viewer. 
+    /** Set information for Swing GUI viewer.
      *  @param viewerData  Private data for RepTreeModel
      */
     public void setViewerData (Property viewerData)
@@ -2169,75 +2230,69 @@ public class NisoImageMetadata
 	_viewerData = viewerData;
     }
 
-    /*  Canonicizes (canonizes? whatever) a date to ISO
+    /*  Normalizes a date to ISO
      *  8601 format.  Returns null if it can't make sense of
      *  it.  Returns the date unchanged if it's already
-     *  canonical. Initially this converts TIFF dates to ISO.
+     *  in ISO format. Initially this converts TIFF dates to ISO.
      */
-    private String make8601Valid (String date)
-    {
-        try {
-            if (date.charAt (4) == ':') {
-                // It's a TIFF date, or a good imitation of one.
-                // TIFF dates have exact offsets, making things easy.
-                String yr = date.substring (0, 4);
-                String mo = date.substring (5, 7);
-                String da = date.substring (8, 10);
-                String hr = date.substring (11, 13);
-                String mi = date.substring (14, 16);
-                String se = date.substring (17, 19);
-                return yr + "-" + mo + "-" + da + "T" +
-                    hr + ":" + mi + ":" + se;
+    protected static String make8601Valid(String date) {
+        final Pattern pIsoDate = Pattern.compile("(\\d{4})\\-([01]\\d)\\-([0-3]\\d)T([0-2]\\d):([0-5]\\d):([0-5]\\d)");
+        final Pattern pTiffDate = Pattern.compile("(\\d{4}).([01]\\d).([0-3]\\d).([0-2]\\d).([0-5]\\d).([0-5]\\d)");
+        if (pIsoDate.matcher(date).matches()) {
+          return date;
+        }
+        Matcher m = pTiffDate.matcher(date);
+        if (m.matches()) {
+            String isoDate = String.format("%s-%s-%sT%s:%s:%s", 
+                m.group(1), m.group(2), m.group(3), m.group(4), m.group(5), m.group(6));
+            if (pIsoDate.matcher(isoDate).matches()) {
+                return isoDate;
             }
-            return date;  // default
-        }
-        catch (Exception e) {
-            // Malformed date
-            return null;
         }
+        return null;
     }
-    
+
     public static String extractIccProfileDescription(byte[] data) throws IllegalArgumentException {
     	// Validate the ICCProfile with the java library
-    	ICC_Profile profile = ICC_Profile.getInstance(data);
-    	// Extract the 'desc' record (cf http://www.color.org/ICC1-V41.pdf) 
-    	byte[] dataProf = profile.getData(ICC_Profile.icSigProfileDescriptionTag);
+        ICC_Profile profile = ICC_Profile.getInstance(data);
+    	// Extract the 'desc' record (cf http://www.color.org/ICC1-V41.pdf)
+        byte[] dataProf = profile.getData(ICC_Profile.icSigProfileDescriptionTag);
     	if (dataProf == null) {
     		return null;
     	}
 
     	String description = null;
-    	ByteBuffer bb = ByteBuffer.wrap(dataProf).asReadOnlyBuffer();
-    	
-    	LOGGER.fine("Version " + profile.getMajorVersion());
-    	if (profile.getMajorVersion() <= 2) {
+        ByteBuffer bb = ByteBuffer.wrap(dataProf).asReadOnlyBuffer();
+        int majorVersion = profile.getMajorVersion();
+        int minorVersion = profile.getMinorVersion();
+        LOGGER.fine("Version " + majorVersion + "." + minorVersion);
+
+        int beginTag = bb.getInt(0);
+        if (beginTag == ICC_Profile.icSigProfileDescriptionTag) {
+            // Invariant option
         	// ICC v2 http://www.color.org/ICC_Minor_Revision_for_Web.pdf
 	    	// Read only the ASCII form (cf 6.5.17 ICC v2)
 	    	final int OFFSET_LENGTH = 8;
 	    	final int OFFSET_DESC = OFFSET_LENGTH + 4;
-	    	
+
 	    	int lengthAscii = bb.getInt(OFFSET_LENGTH);
-	    	
+
 	    	// readString
 	    	byte[] asciiDesc = new byte[lengthAscii -1];
 	    	bb.position(OFFSET_DESC);
 	    	bb.get(asciiDesc);
-	    	
-			try {
-				description = new String(asciiDesc, "US-ASCII");
-			} catch (UnsupportedEncodingException e) {
-				// IGNORE: US-ASCII always there... wait for Java 1.7
-			}
+
+			description = new String(asciiDesc, StandardCharsets.US_ASCII);
     	} else {
         	// ICC v4 http://www.color.org/ICC1-V41.pdf
-	    	final int OFFSET_NUMBER = 8;
+            final int OFFSET_NUMBER = 8;
 	    	final int MLUC_TAG = 0x6D6C7563;
 	    	final int OFFSET_NAME_LENGTH = 20;
 	    	final int OFFSET_NAME_OFFSET = 24;
-	    	
+
     		// 6.2 segment tag table definition
-    		int tagMluc = bb.getInt(0);
-    		
+            int tagMluc = bb.getInt(0);
+
         	// Read the 1st mulc form (cf 6.5.12 ICC v4)
     		int nb =  bb.getInt(OFFSET_NUMBER);
     		if (tagMluc != MLUC_TAG || nb < 1) {
@@ -2245,22 +2300,16 @@ public class NisoImageMetadata
     		}
     		int firstNameLength = bb.getInt(OFFSET_NAME_LENGTH);
     		int firstNameOffset = bb.getInt(OFFSET_NAME_OFFSET);
-    		
         	// readString
         	byte[] desc = new byte[firstNameLength];
         	bb.position(firstNameOffset);
         	bb.get(desc);
-        	
-    		try {
-    			// The  Unicode  strings  in  storage  are  encoded  as  16-bit
-    			// big-endian,  UTF-16BE,  and should not be NULL terminated.
-    			description = new String(desc, "UTF-16BE");
-    		} catch (UnsupportedEncodingException e) {
-    			// IGNORE: UTF-16 always there... wait for Java 1.7
-    		}
-    		
+
+            // The  Unicode  strings  in  storage  are  encoded  as  16-bit
+            // big-endian,  UTF-16BE,  and should not be NULL terminated.
+            description = new String(desc, StandardCharsets.UTF_16BE);
     	}
     	return description;
     }
-    
+
 }
