@@ -15,11 +15,12 @@ public class IdatChunk extends PNGChunk {
 	
 	/** Process the chunk. We don't analyze or report the data, but
 	 *  we enforce the requirement that IDAT chunks must be consecutive. */
+	@Override
 	public void processChunk(RepInfo info) throws Exception {
 		processChunkCommon(info);
 		_module.setIdatSeen(true);
 		if (_module.isIdatFinished()) {
-			ErrorMessage msg = new ErrorMessage("IDAT chunks are not consecutive in file");
+			ErrorMessage msg = new ErrorMessage(MessageConstants.PNG_GDM_20);
 			info.setMessage(msg);
 			info.setWellFormed(false);
 			throw new PNGException ("Misplaced IDAT chunk");
